summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteonlinestatusmanager.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2bc1d72869b62af05ae4feafd878203b526da8c5 (patch)
tree2676903bb600bd9646644856e354940471ad84e2 /kopete/libkopete/kopeteonlinestatusmanager.h
parent937b2991d8e78166eea904c80ad04d34607017a4 (diff)
downloadtdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.tar.gz
tdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopeteonlinestatusmanager.h')
-rw-r--r--kopete/libkopete/kopeteonlinestatusmanager.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/libkopete/kopeteonlinestatusmanager.h b/kopete/libkopete/kopeteonlinestatusmanager.h
index 0ce2f983..547e47d8 100644
--- a/kopete/libkopete/kopeteonlinestatusmanager.h
+++ b/kopete/libkopete/kopeteonlinestatusmanager.h
@@ -107,15 +107,15 @@ public:
/**
* insert "settqStatus" actions from the given account to the specified actionMenu.
* (actions have that menu as tqparent TQObject)
* they are connected to the Account::setOnlineStatus signal
*
* Items are stored by status height.
*
* @param account the account
* @param tqparent the ActionMenu where action are inserted
*/
- void createAccountStatusActions( Account *account , KActionMenu *tqparent);
+ void createAccountStatusActions( Account *account , KActionMenu *parent);
/**
* return the status of the @p protocol which is in the category @p category
@@ -154,7 +154,7 @@ class OnlineStatusAction : public KAction
Q_OBJECT
TQ_OBJECT
public:
- OnlineStatusAction ( const OnlineStatus& status, const TQString &text, const TQIconSet &pix, TQObject *tqparent=0, const char *name=0);
+ OnlineStatusAction ( const OnlineStatus& status, const TQString &text, const TQIconSet &pix, TQObject *parent=0, const char *name=0);
signals:
void activated( const Kopete::OnlineStatus& status );
private slots:
@@ -107,15 +107,15 @@ public:
/**
* insert "settqStatus" actions from the given account to the specified actionMenu.
- * (actions have that menu as tqparent TQObject)
+ * (actions have that menu as parent TQObject)
* they are connected to the Account::setOnlineStatus signal
*
@@ -107,15 +107,15 @@ public:
*
* @param account the account
- * @param tqparent the ActionMenu where action are inserted
+ * @param parent the ActionMenu where action are inserted
*/